Ivan Kokshaysky wrote:
> On Wed, Feb 02, 2000 at 07:44:45PM -0800, Richard Henderson wrote:
> > Ok, this stood up to an hour's pounding of an ide cdrom.
> > It's a delta from the previous patch.
>
> Works just great, thanks!
> This minor addition fixes unresolved symbols in some of my modules.
Also in the anal-retentive department (actually found this because
I was grep'ing for the implementation and I can't spell either...)
-Mitch
--- include/asm-alpha/pci.h.OLD Fri Feb 4 10:35:37 2000
+++ include/asm-alpha/pci.h Fri Feb 4 10:36:04 2000
@@ -56,16 +56,16 @@
/* IOMMU controls. */
/* Allocate and map kernel buffer using consistant mode DMA for PCI
device. Returns non-NULL cpu-view pointer to the buffer if
successful and sets *DMA_ADDRP to the pci side dma address as well,
else DMA_ADDRP is undefined. */
extern void *pci_alloc_consistent(struct pci_dev *, long, dma_addr_t *);
-/* Free and unmap a consistant DMA buffer. CPU_ADDR and DMA_ADDR must
- be values that were returned from pci_alloc_consistant. SIZE must
- be the same as what as passed into pci_alloc_consistant.
+/* Free and unmap a consistent DMA buffer. CPU_ADDR and DMA_ADDR must
+ be values that were returned from pci_alloc_consistent. SIZE must
+ be the same as what as passed into pci_alloc_consistent.
References to the memory and mappings assosciated with CPU_ADDR or
DMA_ADDR past this call are illegal. */
@@ -108,7 +108,7 @@
extern void pci_unmap_sg(struct pci_dev *, struct scatterlist *, int);
/* Make physical memory consistant for a single streaming mode DMA
translation after a transfer.
If you perform a pci_map_single() but wish to interrogate the
@@ -123,7 +123,7 @@
/* Nothing to do. */
}
/* Make physical memory consistant for a set of streaming mode DMA
translations after a transfer. The same as pci_dma_sync_single but
for a scatter-gather list, same rules and usage. */
-- To unsubscribe: send e-mail to axp-list-request@redhat.com with 'unsubscribe' as the subject. Do not send it to axp-list@redhat.com
This archive was generated by hypermail version 2a22 on Wed Mar 1 06:26:22 2000 PST
Send any problems or questions about this archive to webmaster@alphalinux.org.
@@ -56,16 +56,16 @@
/* IOMMU controls. */
-/* Allocate and map kernel buffer using consistant mode DMA for PCI
+/* Allocate and map kernel buffer using consistent mode DMA for PCI
device. Returns non-NULL cpu-view pointer to the buffer if
successful and sets *DMA_ADDRP to the pci side dma address as well,
@@ -108,7 +108,7 @@
extern void pci_unmap_sg(struct pci_dev *, struct scatterlist *, int);
-/* Make physical memory consistant for a single streaming mode DMA
+/* Make physical memory consistent for a single streaming mode DMA
translation after a transfer.
If you perform a pci_map_single() but wish to interrogate the
@@ -123,7 +123,7 @@
/* Nothing to do. */
}
-/* Make physical memory consistant for a set of streaming mode DMA
+/* Make physical memory consistent for a set of streaming mode DMA
translations after a transfer. The same as pci_dma_sync_single but
for a scatter-gather list, same rules and usage. */